Page 105 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 105

Home

    Today the interlocking Farben and Rockefeller
    interests are the largest chemical and drug cartel in the
    world. This cartel plays a major role in the promotion of
    drug-oriented medicine and against the use of natural
    products, such as vitamins, especially in controlling

    cancer.

    For more information about the Farben, Rockefeller
    drug cartel, we recommend G. Edward Griffin's book
    World Without Cancer: The Story of Vitamin B17. It is

    Westlake Village, California.

    To accomplish their war-making plans on this side of
    the ocean, the international bankers set up a money crisis
    in the United States. The crisis was the Great Depression

    ce 41aAnn om

    The first step was for the Federal Reserve to expand
    the money supply by 62 percent between 1923 and 1929,
    thus creating a false aura of prosperity. It was then made
    possible to purchase stocks on extensive credit with bank
    loans to cover up to 90 percent of the purchase. The
    catch was that these loans could be called in at any time,

    and if called in, had to be repaid within 24 hours.

    To cover themselves, the Money Barons got out of
    the stock market before they started calling in the 24
    hour loans. The panic that followed caused the market to
    crash resulting in bank runs that forced thousands of
    banks to close. While this was going on, the Federal
    Reserve did nothing to relieve the situation. To make

    100

    The Secret Side of History

    of 1929. The solution offered was to make a socialist

    nation out of the United States.